@@ -4,7 +4,7 @@ package Faker;
 use Faker::Base;
 use Faker::Function qw(confess tryload);
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 has locale => (
     is      => 'ro',
@@ -18,11 +18,21 @@ has namespace => (
     default => 'Faker::Provider',
 );
 
+has providers => (
+    is      => 'ro',
+    isa     => HASH,
+    default => fun {{}},
+);
+
 method provider (STRING $name) {
+    my $providers = $self->providers;
     my $namespace = $self->namespace;
     my $locale    = $self->locale;
     my $default   = 'en_US';
 
+    return $providers->{$name}
+        if $providers->{$name};
+
     my @classes;
     my $explicit  = $locale && $locale ne $default;
 
@@ -31,7 +41,8 @@ method provider (STRING $name) {
     push @classes, join '::', $namespace, $name;
 
     for my $class (@classes) {
-        return $class->new(factory => $self) if tryload $class;
+        next unless tryload $class;
+        return $providers->{$name} = $class->new(factory => $self);
     }
 
     my $classes = join ' or ', @classes;
@@ -268,7 +279,7 @@ Faker - Extensible Fake Data Generator
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -442,7 +453,7 @@ C<street_suffix> method on the L<Faker::Provider::Address> class.
 
 =head2 color_hex_code
 
-    $faker->color_hex_code; # #af0573
+    $faker->color_hex_code; # af0573
 
 The color_hex_code method generates a random ficticious hex color. This method
 is a proxy method which is the equivalent of calling the C<hex_code> method on
@@ -466,7 +477,7 @@ method on the L<Faker::Provider::Color> class.
 
 =head2 color_rgbcolors_array
 
-    $faker->color_rgbcolors_array; # ARRAY(0x24d8788)
+    $faker->color_rgbcolors_array; # [214,199,200]
 
 The color_rgbcolors_array method generates a random ficticious rgb colors.
 This method is a proxy method which is the equivalent of calling the
@@ -482,7 +493,7 @@ C<rgbcolors_css> method on the L<Faker::Provider::Color> class.
 
 =head2 color_safe_hex_code
 
-    $faker->color_safe_hex_code; # #ff0097
+    $faker->color_safe_hex_code; # ff0097
 
 The color_safe_hex_code method generates a random ficticious safe hex color.
 This method is a proxy method which is the equivalent of calling the
