@@ -5,14 +5,14 @@ use Faker::Base;
 
 extends 'Faker::Provider';
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 method name () {
-    return $self->process_random('format_for_name');
+    return $self->process(random => 'name');
 }
 
 method name_suffix () {
-    return $self->process_random('data_for_name_suffix');
+    return $self->process(random => 'name_suffix');
 }
 
 1;
@@ -29,7 +29,7 @@ Faker::Provider::Company - Faker Standard Company Provider
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
