@@ -5,7 +5,7 @@ use Faker::Base;
 
 extends 'Faker::Provider';
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 method paragraph (INTEGER :$n_sentences = 4) {
     return $self->sentences(n_sentences => $n_sentences) . "\n\n";
@@ -32,12 +32,12 @@ method sentences (INTEGER :$n_paragraphs = 3, INTEGER :$v_length = 10) {
 }
 
 method word () {
-    return $self->process_random('data_for_word');
+    return $self->process_random('word');
 }
 
 method words (INTEGER :$count = 5) {
     return join ' ', map {
-        $self->process_random('data_for_word')
+        $self->process(random => 'word')
     }   1..$count;
 }
 
@@ -55,7 +55,7 @@ Faker::Provider::Lorem - Faker Standard Lorem Provider
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -63,7 +63,7 @@ version 0.10
     use Faker::Provider::Lorem;
 
     my $faker = Faker->new;
-    my $lorem = Faker::Provider::Internet->new(factory => $faker);
+    my $lorem = Faker::Provider::Lorem->new(factory => $faker);
 
     say $lorem->paragraph;
 
