@@ -5,12 +5,10 @@ use Faker::Base;
 
 extends 'Faker::Provider';
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 method number () {
-    return $self->process_markers(
-        $self->process_random('format_for_number')
-    );
+    return $self->process(random => 'number', all_markers => 1);
 }
 
 1;
@@ -27,7 +25,7 @@ Faker::Provider::Telephone - Faker Standard Telephone Number Provider
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
