@@ -1,11 +1,11 @@
-# ABSTRACT: Faker Localized en_US Telephone Number Provider
+# ABSTRACT: Faker Localized en_US Telephone Provider
 package Faker::Provider::en_US::Telephone;
 
 use Faker::Base;
 
 extends 'Faker::Provider::Telephone';
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 1;
 
@@ -17,27 +17,27 @@ __END__
 
 =head1 NAME
 
-Faker::Provider::en_US::Telephone - Faker Localized en_US Telephone Number Provider
+Faker::Provider::en_US::Telephone - Faker Localized en_US Telephone Provider
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
     use Faker;
-    use Faker::Provider::en_US::Person;
+    use Faker::Provider::en_US::Telephone;
 
     my $faker = Faker->new(locale => 'en_US');
-    my $phone = Faker::Provider::en_US::PhoneNumber->new(factory => $faker);
+    my $phone = Faker::Provider::en_US::Telephone->new(factory => $faker);
 
     say $phone->number;
 
 =head1 DESCRIPTION
 
-Faker::Provider::en_US::PhoneNumber is a L<Faker> provider localized under
-en_US, which provides fake phone data. Faker::Provider::en_US::PhoneNumber
-inherits all attributes and methods from L<Faker::Provider::PhoneNumber> and
+Faker::Provider::en_US::Telephone is a L<Faker> provider localized under
+en_US, which provides fake phone data. Faker::Provider::en_US::Telephone
+inherits all attributes and methods from L<Faker::Provider::Telephone> and
 implements the following new ones. B<Note: This is an early release available
 for testing and feedback and as such is subject to change.>
 
